﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using RDotNet;


namespace RtoCSharp
{
    
    class Program
    {

        
        static void Main(string[] args)
        {

            REngine.SetEnvironmentVariables();
            REngine engine = REngine.GetInstance();
            engine.Initialize();

            NumericVector exposureCount = engine.CreateNumericVector(new double[] { 3});
            NumericVector simNumber  = engine.CreateNumericVector(new double[] { 10});
            NumericVector riskLessRate = engine.CreateNumericVector(new double[] { 0.03});
            NumericVector EAD_per_Exposure  = engine.CreateNumericVector(new double[] { 4000000, 1000000, 10000000});
            NumericVector OverallLGD  = engine.CreateNumericVector(new double[] { 0.45});
            NumericVector corr  = engine.CreateNumericVector(new double[] { 0.4});
            CharacterVector BorrowerRatings  = engine.CreateCharacterVector(new string[] { "B1", "A2", "B3"});
            NumericVector ConfidenceLevel  = engine.CreateNumericVector(new double[] { 0.99});
            NumericMatrix rho  = engine.CreateNumericMatrix(new double[,] {{1.0, 0.4, 0.6}, { 0.4, 1, 0.5}, { 0.6, 0.5, 1}});
            CharacterVector CopulaType = engine.CreateCharacterVector(new string[] { "Student"});
            NumericVector df = engine.CreateNumericVector(new double[] { 10});

            string pathRCode = "C:/Users/R Code";


            //Create an instance of clsRtoCS
            clsRtoCS rtoCS = new clsRtoCS();


            //randomly generate a hypothetical portfolio
            DataFrame getPortfolio = rtoCS.RandomPortfolio(pathRCode);


            //create transition matrix using the hypothetical portfolio (continuous time markov chain)
            NumericMatrix CTMC = rtoCS.getTransitionMatrix(getPortfolio, pathRCode);


            //run the CreditMetrics 
            NumericMatrix cm_CVaR = rtoCS.runCreditMetrics(CTMC, exposureCount, simNumber, riskLessRate, 
                         EAD_per_Exposure, OverallLGD, corr, BorrowerRatings, ConfidenceLevel, rho, CopulaType, df, pathRCode);

            Console.WriteLine(cm_CVaR);

            engine.Dispose();

        }
    }
}
